(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[      6476,        195]
NotebookOptionsPosition[      5856,        169]
NotebookOutlinePosition[      6211,        185]
CellTagsIndexPosition[      6168,        182]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
For completeness here we solve the equation for bactarial remediation in \
Chapter 6 with flow and transport. The governing equation is\
\>", "Text",
 CellChangeTimes->{{3.699614172881459*^9, 3.699614221390465*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"eq", ":=", 
    RowBox[{
     RowBox[{
      RowBox[{"S", "'"}], "[", "x", "]"}], "\[Equal]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"kd", "*", "K", "*", 
         RowBox[{"(", 
          RowBox[{"kd", "-", "alpha"}], ")"}], "*", 
         RowBox[{"S", "[", "x", "]"}]}], "+", 
        RowBox[{"kd", "*", "G"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"u", "*", "alpha", "*", 
        RowBox[{"S", "[", "x", "]"}], "*", "Y"}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.699614038670027*^9, 3.69961409303899*^9}, {
  3.699614166907748*^9, 3.699614167446766*^9}, {3.699614209466539*^9, 
  3.6996142249922247`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["eq"], "Input",
 CellChangeTimes->{{3.6996140953162117`*^9, 3.699614096305993*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["S", "\[Prime]",
    MultilineFunction->None], "[", "x", "]"}], "\[Equal]", 
  FractionBox[
   RowBox[{
    RowBox[{"G", " ", "kd"}], "+", 
    RowBox[{"K", " ", "kd", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "alpha"}], "+", "kd"}], ")"}], " ", 
     RowBox[{"S", "[", "x", "]"}]}]}], 
   RowBox[{"alpha", " ", "u", " ", "Y", " ", 
    RowBox[{"S", "[", "x", "]"}]}]]}]], "Output",
 CellChangeTimes->{3.699614098064857*^9, 3.6996142264330997`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DSolve", "[", 
   RowBox[{"eq", ",", "S", ",", "x"}], "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.6996141013479652`*^9, 3.699614117271874*^9}, {
  3.699614151722269*^9, 3.699614153507723*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Solve", "::", "ifun"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Inverse functions are being used by \
\[NoBreak]\\!\\(Solve\\)\[NoBreak], so some solutions may not be found; use \
Reduce for complete solution information. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/Solve/ifun\\\", ButtonNote -> \
\\\"Solve::ifun\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.699614117615192*^9, 3.699614154711629*^9, 
  3.699614228286928*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"S", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", "x", "}"}], ",", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"K", " ", 
         RowBox[{"(", 
          RowBox[{"alpha", "-", "kd"}], ")"}]}]], 
       RowBox[{"G", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"ProductLog", "[", 
           RowBox[{"-", 
            FractionBox[
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               FractionBox["alpha", 
                RowBox[{
                 RowBox[{"-", "alpha"}], "+", "kd"}]], "-", 
               FractionBox["kd", 
                RowBox[{
                 RowBox[{"-", "alpha"}], "+", "kd"}]], "-", 
               FractionBox[
                RowBox[{"alpha", " ", 
                 SuperscriptBox["K", "2"], " ", "kd", " ", "x"}], 
                RowBox[{"G", " ", "u", " ", "Y"}]], "+", 
               FractionBox[
                RowBox[{"2", " ", 
                 SuperscriptBox["K", "2"], " ", 
                 SuperscriptBox["kd", "2"], " ", "x"}], 
                RowBox[{"G", " ", "u", " ", "Y"}]], "-", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["K", "2"], " ", 
                 SuperscriptBox["kd", "3"], " ", "x"}], 
                RowBox[{"alpha", " ", "G", " ", "u", " ", "Y"}]], "+", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["alpha", "2"], " ", 
                 SuperscriptBox["K", "2"], " ", 
                 RowBox[{"C", "[", "1", "]"}]}], "G"], "-", 
               FractionBox[
                RowBox[{"2", " ", "alpha", " ", 
                 SuperscriptBox["K", "2"], " ", "kd", " ", 
                 RowBox[{"C", "[", "1", "]"}]}], "G"], "+", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["K", "2"], " ", 
                 SuperscriptBox["kd", "2"], " ", 
                 RowBox[{"C", "[", "1", "]"}]}], "G"]}]], "G"]}], "]"}]}], 
         ")"}]}]}]}], "]"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.6996141176169643`*^9, 3.6996141552367487`*^9, 
  3.6996142282907333`*^9}]
}, Open  ]],

Cell["\<\
This is a mess as was stated in the notes, but let\[CloseCurlyQuote]s explore \
a few things  - in Matlab\
\>", "Text",
 CellChangeTimes->{{3.699614236443639*^9, 3.699614249087986*^9}, {
  3.6996143775870333`*^9, 3.6996143825811872`*^9}, {3.699614920840795*^9, 
  3.699614923450819*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.699614384659533*^9, 3.6996144618273573`*^9}, 
   3.699614664128647*^9, {3.699614703740439*^9, 3.699614705146319*^9}, 
   3.699614918852273*^9}]
},
WindowSize->{808, 858},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 4, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 225, 4, 49, "Text"],
Cell[786, 26, 776, 21, 80, "Input"],
Cell[CellGroupData[{
Cell[1587, 51, 96, 1, 28, "Input"],
Cell[1686, 54, 519, 15, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2242, 74, 250, 6, 46, "Input"],
Cell[2495, 82, 578, 12, 41, "Message"],
Cell[3076, 96, 2215, 56, 154, "Output"]
}, Open  ]],
Cell[5306, 155, 297, 6, 30, "Text"],
Cell[5606, 163, 246, 4, 63, "Input"]
}
]
*)

(* End of internal cache information *)
